@@ -45,7 +45,7 @@ App::App(QObject* parent)
         qCInfo(BALOO) << "Busy, paced indexing";
         m_isBusy = true;
     });
-    connect(m_idleTime, qOverload<int, int>(&KIdleTime::timeoutReached), this, [this]() {
+    connect(m_idleTime, &KIdleTime::timeoutReached, this, [this]() {
         qCInfo(BALOO) << "Not busy, fast indexing";
         m_isBusy = false;
     });
